/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.spi.discovery.zk.internal;

import org.apache.ignite.internal.util.typedef.internal.S;
import org.apache.ignite.spi.discovery.DiscoverySpiCustomMessage;
import org.jetbrains.annotations.Nullable;

/**
 * Zk Force Node Fail Message.
 */
public class ZkForceNodeFailMessage implements DiscoverySpiCustomMessage, ZkInternalMessage {
    /** */
    private static final long serialVersionUID = 0L;

    /** */
    final long nodeInternalId;

    /** */
    final String warning;

    /**
     * @param nodeInternalId Node ID.
     * @param warning Warning to be displayed on all nodes.
     */
    ZkForceNodeFailMessage(long nodeInternalId, String warning) {
        this.nodeInternalId = nodeInternalId;
        this.warning = warning;
    }

    /** {@inheritDoc} */
    @Nullable @Override public DiscoverySpiCustomMessage ackMessage() {
        return null;
    }

    /** {@inheritDoc} */
    @Override public boolean isMutable() {
        return false;
    }

    /** {@inheritDoc} */
    @Override public boolean stopProcess() {
        return false;
    }

    /** {@inheritDoc} */
    @Override public String toString() {
        return S.toString(ZkForceNodeFailMessage.class, this);
    }
}
